@@ -2,12 +2,12 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: klogwidget.cpp,v 0.20 2002/05/09 15:37:46 mj Exp $
+ * $Id: klogwidget.cpp,v 0.22 2003/02/19 21:34:46 mj Exp $
  *
  * QMultiLineEdit based widget for viewing log files
  *
  *****************************************************************************
- * Copyright (C) 2000
+ * Copyright (C) 2000-2003
  *  _____ _____
  * |     |___  |   Martin Junius             Internet:  mailto:mj@m-j-s.net
  * | | | |   | |   Radiumstr. 18                        http://www.m-j-s.net/
@@ -144,12 +144,13 @@ bool KLogFile::readMore()
  * KLogWidget
  */
 KLogWidget::KLogWidget(QWidget *parent, kwatchConf &cf)
-    : QMultiLineEdit(parent), m_cf(cf), m_popup(0),
+    : QTextEdit(parent),
+      m_cf(cf), m_popup(0),
       m_timer(0), m_files(0), m_current(0),
       m_r(0), m_c(0)
 {
     // set QMultiLineEdit parameters
-    setReadOnly( TRUE );
+    setReadOnly(TRUE);
 
     // set configuration parameters
     updateConf();
@@ -157,6 +158,9 @@ KLogWidget::KLogWidget(QWidget *parent, kwatchConf &cf)
     // accept drops
     setAcceptDrops(true);
 
+    setTextFormat(PlainText);
+    setWordWrap(NoWrap);
+    
     // start timer
     m_timer = new QTimer( this );
     m_timer->start(0);
@@ -194,7 +198,7 @@ void KLogWidget::setPopupMenu(QPopupMenu *popup)
 
 void KLogWidget::clear()
 {
-    QMultiLineEdit::clear();
+    QTextEdit::clear();
     m_r = m_c = 0;
 }
 
@@ -208,7 +212,7 @@ void KLogWidget::mousePressEvent(QMouseEvent *e)
     }
     else 
     {
-	QMultiLineEdit::mousePressEvent(e);
+	QTextEdit::mousePressEvent(e);
     }
 }
 
@@ -261,36 +265,34 @@ void KLogWidget::timeout()
 
 void KLogWidget::moreText(KLogFile *f, QString s)
 {
-    if (s.isEmpty()) return;
+    if(s.isEmpty())
+	return;
 
     QString more = s;
 
-    if(f && f != m_current )
+    if(f && f != m_current)
     {
         m_current = f;
         more.prepend(formatName(f->m_file->name()));
     }
 
-    // disable autoUpdate to avoid flicker
-    setAutoUpdate(false);
-
     // insert new text
-    insertAt(more, m_r, m_c);
+    append(more);
+    moveCursor(MoveEnd, FALSE);
+    ensureCursorVisible();
 
     // remove lines at beginning if necessary
-    for(int l = numLines() - m_cf.maxlines; l > 0; l--)
-        removeLine(0);
-    m_r = numLines() - 1;
-    while(0 == (m_c = lineLength(m_r)) && m_r > 0)
-	m_r--;
-    if(more.right(1) == "\n")
-	m_r++;
-
-    // enable autoUpdate and repaint
-    setAutoUpdate(true);
-    repaint(false);
-    
-    setCursorPosition(numLines()-1, 0);
+    int l = paragraphs() - m_cf.maxlines;
+    if(l > 0) 
+    {
+	// disable updates while removing to make this a bit faster
+	// for several lines/paragraphs at once
+	setUpdatesEnabled(FALSE);
+	while(l-- > 0)
+	    removeParagraph(0);
+	setUpdatesEnabled(TRUE);
+	update();
+    }
 }
 
 
