@@ -2,12 +2,12 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: klogwidget.h,v 0.15 2001/09/08 18:43:21 mj Exp $
+ * $Id: klogwidget.h,v 0.16 2003/02/16 15:03:30 mj Exp $
  *
  * QMultiLineEdit based widget for viewing log files
  *
  *****************************************************************************
- * Copyright (C) 2000
+ * Copyright (C) 2000-2003
  *  _____ _____
  * |     |___  |   Martin Junius             Internet:  mailto:mj@m-j-s.net
  * | | | |   | |   Radiumstr. 18                        http://www.m-j-s.net/
@@ -91,7 +91,8 @@ private:
  * @short Log Widget
  * @author Ralph Weichert <Ralph.Weichert@physik.tu-darmstadt.de>
  */
-class KLogWidget : public QMultiLineEdit
+//class KLogWidget : public QMultiLineEdit
+class KLogWidget : public QTextEdit
 {
     Q_OBJECT
 
